==> oligotyping-1.6.tar.gz: oligotyping-1.6/README.md <==
Oligotyping
===============================================================================

Oligotyping is a novel supervised computational method to decompose very closely related 
taxa within microbial communities by utilizing very subtle nucleotide variation
among 16S Ribosomal RNA gene amplicon reads. It can reveal previously unobserved
ecological patterns, and hidden diversity concealed within environmental datasets.

With oligotyping, depending on the hyper-variable region, similarity threshold
between different types can be as low as 0.2%, more than a magnitude lower than
de facto 3% similarity threshold that is being used by OTU clustering methods.

Here you can find some information about this codebase and learn more about the
oligotyping:

* http://oligotyping.org

For installation and usage instructions, please see the tutorial:

* http://oligotyping.org/2012/05/11/oligotyping-pipeline-explained/


Licence
===============================================================================

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.



Author
===============================================================================

I am an assistant research scientist at the [Marine Biological Laboratory](http://mbl.edu), [The Josephine
Bay Paul Center for Comparative Molecular Biology and Evolution](http://jbpc.mbl.edu/), in Woods Hole
Massachusetts, studying microbial ecology.


http://meren.org

==> oligotyping-2.1.tar.gz: oligotyping-2.1/README.md <==
Oligotyping
===============================================================================

Oligotyping is a novel supervised computational method to decompose very closely related 
taxa within microbial communities by utilizing very subtle nucleotide variation
among 16S Ribosomal RNA gene amplicon reads. It can reveal previously unobserved
ecological patterns, and hidden diversity concealed within environmental datasets.

With oligotyping, depending on the hyper-variable region, similarity threshold
between different types can be as low as 0.2%, more than a magnitude lower than
de facto 3% similarity threshold that is being used by OTU clustering methods.

For installation and usage instructions, please see the project web page:

* https://meren.github.io/projects/oligotyping/


Licence
===============================================================================

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.



Author
===============================================================================

I am an assistant research scientist at the [Marine Biological Laboratory](http://mbl.edu), [The Josephine
Bay Paul Center for Comparative Molecular Biology and Evolution](http://jbpc.mbl.edu/), in Woods Hole
Massachusetts, studying microbial ecology.


http://meren.org
